/*
 * This file is part of the Scandit Data Capture SDK
 *
 * Copyright (C) 2023- Scandit AG. All rights reserved.
 */

import 'dart:convert';

import 'package:flutter/services.dart';
import 'package:scandit_flutter_datacapture_core/scandit_flutter_datacapture_core.dart';

import 'captured_id.dart';
import 'function_names.dart';
import 'result/aamva_cloud_verification_result.dart';

class AamvaCloudVerifier {
  final _AamvaCloudVerifierController _controller;
  // ignore: unused_field
  DataCaptureContext? _context;

  AamvaCloudVerifier._(this._controller);

  static Future<AamvaCloudVerifier> create(DataCaptureContext context) {
    var verifier = AamvaCloudVerifier._(_AamvaCloudVerifierController());
    return verifier._controller.create().then((value) {
      verifier._context = context;
      return verifier;
    });
  }

  Future<AamvaCloudVerificationResult> verify(CapturedId capturedId) {
    return _controller.verify(capturedId);
  }
}

class _AamvaCloudVerifierController {
  final MethodChannel _methodChannel = MethodChannel(IdCaptureFunctionNames.methodsChannelName);

  Future<void> create() {
    return _methodChannel.invokeMethod(IdCaptureFunctionNames.createAamvaCloudVerifier);
  }

  Future<AamvaCloudVerificationResult> verify(CapturedId captureId) {
    return _methodChannel
        .invokeMethod(IdCaptureFunctionNames.verifyCapturedIdCloud, jsonEncode(captureId.toMap()))
        .then((value) => AamvaCloudVerificationResult.fromJSON(jsonDecode(value)));
  }
}
